Manimpango Reference
====================

.. autosummary::
   :toctree: reference

   manimpango.TextSetting
   manimpango.PangoUtils
   manimpango.text2svg
   manimpango.MarkupUtils
   manimpango.register_font
   manimpango.unregister_font
   manimpango.list_fonts

Enums
=====
.. autosummary::
   :toctree: reference

   manimpango.Style
   manimpango.Weight
   manimpango.Variant
